.onLoad <- function(libname, pkgname) {
  extdata_dirpath <- system.file("extdata", package=pkgname,
                                 lib.loc=libname, mustWork=TRUE)

  ## fetch the metadata from the smallest file to minimize loading time
  finfo <- file.info(list.files(pattern=sprintf("%s\\.AF\\.", pkgname), path=extdata_dirpath,
                                full.names=TRUE))
  obj <- readRDS(file.path(extdata_dirpath, basename(rownames(finfo)[which.min(finfo$size)])))
  mdobj <- metadata(obj)
  stopifnot(identical(pkgname, mdobj$data_pkgname)) ## QC
  popname <- basename(rownames(finfo)[which.min(finfo$size)])
  popname <- gsub("\\..+$", "", gsub(sprintf("%s.", pkgname), "", popname))
  if (popname %in% seqlevels(mdobj$reference_genome))
    popname <- "default"

  serializedobjs <- rownames(finfo)
  names(serializedobjs) <- serializedobjs

  ## Make and export MafDb object.
  gsco <- GScores(provider=mdobj$provider,
                  provider_version=mdobj$provider_version,
                  download_url=mdobj$download_url,
                  download_date=mdobj$download_date,
                  reference_genome=mdobj$reference_genome,
                  data_pkgname=pkgname,
                  data_dirpath=extdata_dirpath,
                  data_serialized_objnames=serializedobjs,
                  default_pop="AF",
                  data_group="MAF",
                  data_tag="ESP")

  gscopops <- get(pkgname, envir=gsco@.data_cache)
  gscopops[[popname]] <- list()
  gscopops[[popname]][[mdobj$seqname]] <- obj
  assign(pkgname, gscopops, envir=gsco@.data_cache)

  ns <- asNamespace(pkgname)
  assign(pkgname, gsco, envir=ns)

  namespaceExport(ns, pkgname)
}

.onAttach <- function(libname, pkgname) {
  msg <- paste("The package MafDb.ESP6500SI.V2.SSA137.GRCh38 has been deprecated",
               "and will be removed in the next release of Bioconductor.",
               "Larger and deeper catalogs of human variation in exomes can be",
               "found in packages MafDb.ExAC.r1.0.GRCh38, MafDb.ExAC.r1.0.nonTCGA.GRCh38",
               "and MafDb.gnomADex.r2.1.GRCh38. Please go to their corresponding",
               "package landing web pages at:",
               "https://bioconductor.org/packages/MafDb.ExAC.r1.0.GRCh38",
               "https://bioconductor.org/packages/MafDb.ExAC.r1.0.nonTCGA.GRCh38",
               "https://bioconductor.org/packages/MafDb.gnomADex.r2.1.GRCh38.",
               "and follow the instructions to install them.", sep="\n")

  packageStartupMessage(msg)
}
