\name{MafDb.ESP6500SI.V2.SSA137.GRCh38-package}
\alias{MafDb.ESP6500SI.V2.SSA137.GRCh38-package}
\alias{MafDb.ESP6500SI.V2.SSA137.GRCh38}
\docType{package}

\title{
Annotation package for minor allele frequency data from the NHLBI ESP project
}
\description{
This annotation package stores minor allele frequency (MAF) data values from the release ESP6500SI-V2 of the NHLBI Exome Sequencing project (ESP). The data are exposed to the user in the form of a \code{\link[GenomicScores]{GScores}} object, named after the package and loaded into main memory only as different chromosomes and populations are being queried. The class definition and methods to access \code{\link[GenomicScores]{GScores}} objects are found in the \code{\link[GenomicScores]{GenomicScores}} software package. To minimize disk space and memory requirements, MAF values larger or equal than 0.1 are stored using two significant digits, while MAF values smaller than 0.1 are stored using one significant digit.

WARNING: The positions associated to these MAF data are based on the
GRCh38 release of the human genome and they were lifted by the NHLBI ESP
from GRCh37. This means, the variants were not called directly on the
GRCh38 human genome reference sequence. Moreover, nonSNVs positions were
lifted to single nucleotide positions and, for this reason, have been
discarded in this package.
}

\format{
  \tabular{ll}{
    \code{\link{MafDb.ESP6500SI.V2.SSA137.GRCh38}} \tab \code{\link[GenomicScores]{GScores}} object containing MAF values from 6503 exomes downloaded on March 2018 from \url{http://evs.gs.washington.edu/evs_bulk_data/ESP6500SI-V2-SSA137.GRCh38-liftover.snps_indels.vcf.tar.gz}. The original data were derived from the human genome release GRCh37 and the data in this package were derived by lifting the associated genomic positions over to GRCh38. See the \code{inst/extdata/README} file from the source code for more information on how to update these data. \cr
  }
}

\author{
R. Castelo
}

\seealso{
  \link[GenomicScores]{GScores-class}
  \link[GenomicScores]{gscores}
  \link[GenomicScores]{GenomicScores}
}

\examples{
library(SNPlocs.Hsapiens.dbSNP149.GRCh38)
library(MafDb.ESP6500SI.V2.SSA137.GRCh38)

ls("package:MafDb.ESP6500SI.V2.SSA137.GRCh38")

mafdb <- MafDb.ESP6500SI.V2.SSA137.GRCh38
mafdb
citation(mafdb)

populations(mafdb)

## lookup allele frequencies for rs1129038, an SNP associated to blue and brown eye colors
## as reported in Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]

## snpdb <- SNPlocs.Hsapiens.dbSNP149.GRCh38
## rng <- snpsById(snpdb, ids="rs1129038")
## rng
## gscores(mafdb, rng)
## gscores(mafdb, GRanges("15:28111713"))
}

\source{
  Tennessen JA, et al. Evolution and functional impact of rare coding
  variation from deep sequencing of human exomes. Science, 337:64-69, 2012.

  Exome Variant Server, NHLBI GO Exome Sequencing Project (ESP), Seattle, WA
  (URL: \url{http://evs.gs.washington.edu/EVS}) [March, 2018, accessed]
}

\keyword{package}
\keyword{data}
